@@ -4,6 +4,7 @@ import sys
 from datetime import datetime
 from random import uniform
 from time import perf_counter, sleep, time
+from typing import List
 
 import numpy as np
 import pkg_resources
@@ -227,9 +228,25 @@ class Utilities:
         return hash(__)
 
     @staticmethod
-    def timestamp():
-        (dt, micro) = datetime.utcnow().strftime('%Y%m%d-%H%M%S.%f').split('.')
-        dt = "%s.%03d" % (dt, int(micro) * 0.001)
+    def timestamp(dt_format: str = None) -> str:
+        """
+        Return a formatted timestamp string of the current UTC time.
+
+        :param dt_format: Optional custom format for the timestamp.
+        :type dt_format: str
+        :return: Formatted timestamp string.
+        :rtype: str
+        """
+        if dt_format is None:
+            # Use default format: 'YYYYMMDD-HHMMSS.milliseconds'
+            now = datetime.utcnow()
+            dt = now.strftime('%Y%m%d-%H%M%S')
+            micro = int(now.microsecond / 1000)
+            dt = f"{dt}.{micro:03d}"
+        else:
+            # Use provided custom format
+            dt = datetime.utcnow().strftime(dt_format)
+
         return dt
 
     @staticmethod
@@ -250,23 +267,57 @@ class Utilities:
         return time()
 
     ##########################
-    # I/O
+    # I/O File Utility Functions
     ##########################
     @staticmethod
-    def write_to_file(filename, text, method: str = "a", add_new_line: bool = True):
+    def write_to_file(filename: str, text: str, method: str = "a", add_new_line: bool = True) -> None:
+        """
+        Write the given text to the specified file.
+
+        :param filename: The name of the file.
+        :type filename: str
+        :param text: The text to be written to the file.
+        :type text: str
+        :param method: The file mode, default is 'a' (append).
+        :type method: str
+        :param add_new_line: Whether to add a new line after the text, default is True.
+        :type add_new_line: bool
+        """
         with open(filename, method) as file:
             if add_new_line:
-                file.write(text + "\n")
+                file.write(f"{text}\n")
             else:
                 file.write(text)
 
     @staticmethod
-    def read_file(filename, method="r"):
-        return open(filename, method).read()
+    def read_file(filename: str, method: str = "r") -> str:
+        """
+        Read the content of the specified file.
+
+        :param filename: The name of the file.
+        :type filename: str
+        :param method: The file mode, default is 'r' (read).
+        :type method: str
+        :return: The content of the file.
+        :rtype: str
+        """
+        with open(filename, method) as file:
+            return file.read()
 
     @staticmethod
-    def read_lines(filename, method="r"):
-        return open(filename, method, encoding="utf8").readlines()
+    def read_lines(filename: str, method: str = "r") -> List[str]:
+        """
+        Read the lines of the specified file.
+
+        :param filename: The name of the file.
+        :type filename: str
+        :param method: The file mode, default is 'r' (read).
+        :type method: str
+        :return: The lines of the file.
+        :rtype: List[str]
+        """
+        with open(filename, method, encoding="utf-8") as file:
+            return file.readlines()
 
     ##########################
     # Assorted
